### Plots new clean ###

install.packages("alphahull")
install.packages("adehabitatHR")
install.packages("concaveman")
install.packages("ggforce")
install.packages("PBSmapping")
install.packages("shipunov")
install.packages("coda")
install.packages("ggspatial")
install.packages("ecospat")

library(ggbiplot)
library(dismo)
library(ggplot2)
library(scater)
library(coefplot)
library(raster)
library(plyr)
library(data.table)
library(scales)
library(ade4)
library(factoextra)
library(biomod2)
library(ecospat)
library(alphahull)
library(adehabitatHR)
library(concaveman)
library(ggforce)
library(rgeos)
library(prcomp)
library(dplyr)


setwd("PATH/SDM/R/plots_new_clean")

col_vec2 = c("deeppink4","indianred4","salmon4", "darkolivegreen", "olivedrab","chartreuse4")
col_fun2 = colorRampPalette(col_vec2)
col_vec3 = c("deeppink4","darkolivegreen","indianred4", "olivedrab","salmon4", "chartreuse4")
col_fun3 = colorRampPalette(col_vec3)
### function for plotting multiple plots with ggplot2 #####

# Multiple plot function
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}


                                #### Boxplots model scores ####

##get models
dom_rr60_ModelOut_5arcmin <- get(load("data/Ensete.ventricosum.dom_rr60_5arcmin.models.out"))
wildModelOut_5arcmin <- get(load("data/Ensete.ventricosum.wild_rr_5arcmin.models.out"))
wild263ModelOut_5arcmin <- get(load("data/Ensete.ventricosum.wild2_rr63_5arcmin.models.out"))

## get models evaluation scores
dom_rr60_ModelOut_5arcmin_scores<-get_evaluations(dom_rr60_ModelOut_5arcmin)
wildModelOut_5arcmin_scores<-get_evaluations(wildModelOut_5arcmin)
wild263ModelOut_5arcmin_scores<-get_evaluations(wild263ModelOut_5arcmin)

## rearrange data
ModEval = melt(dom_rr60_ModelOut_5arcmin_scores)
ModEval = ModEval[which(ModEval$Var2 == "Testing.data"), ]
head(ModEval)

ModEval_w = melt(wildModelOut_5arcmin_scores)
ModEval_w = ModEval_w[which(ModEval_w$Var2 == "Testing.data"), ]
head(ModEval_w)

ModEval_w2 = melt(wild263ModelOut_5arcmin_scores)
ModEval_w2 = ModEval_w2[which(ModEval_w2$Var2 == "Testing.data"), ]
head(ModEval_w2)


model_scores_dom_rr60<-ggplot(ModEval, aes(x = Var1, y = value, fill =  interaction(Var3))) +
  scale_fill_manual("", values = rep(col_fun3(6), each=1)) +
  geom_boxplot(size = 0.8, color = "black") +
  ylim(c(0.25, 1))+
  labs(x = "", y = "model score") +
  theme(
    axis.text = element_text(size = 12),
    panel.border = element_rect(size = 1, fill = NA),
    panel.grid.major = element_line(linetype = 2, color = F, size = 0.5),
    panel.background = element_rect(fill = FALSE, color= "black"),
    legend.position = "bottom",
    axis.title=element_text(size=14),
    legend.text=element_text(size=13.85)
  )

model_scores_w2_63<-ggplot(ModEval_w2, aes(x = Var1, y = value, fill =  interaction(Var3))) +
  scale_fill_manual("", values = rep(col_fun3(6), each=1)) +
  geom_boxplot(size = 0.8, color = "black") +
  ylim(c(0.25, 1))+
  labs(x = "", y = "") +
  theme(
    axis.text = element_text(size = 12),
    panel.border = element_rect(size = 1, fill = NA),
    panel.grid.major = element_line(linetype = 2, color = F, size = 0.5),
    panel.background = element_rect(fill = FALSE, color= "black"),
    legend.position = "bottom",
    axis.title=element_text(size=14),
    legend.text=element_text(size=13.85)
  )

png(file=paste0("enset", "_comparison", "scores", ".", "png"), width = 800, height = 600)
multiplot(model_scores_dom_rr60, model_scores_w2_63, cols=2)
dev.off()

                              #### Boxplots variable importance for individual models ####
####preparation of data####
## get variable importance
(dom_rr60_ModelOut_5arcmin_var_import <- get_variables_importance(dom_rr60_ModelOut_5arcmin))
(wild263ModelOut_5arcmin_var_import <- get_variables_importance(wild263ModelOut_5arcmin))
## make the mean of variable importance by algorithm
apply(dom_rr60_ModelOut_5arcmin_var_import, c(1,2), mean)
apply(wild263ModelOut_5arcmin_var_import, c(1,2), mean)
## rearrange data
VarImport = melt(dom_rr60_ModelOut_5arcmin_var_import)
head(VarImport)
VarImport_w = melt(wild263ModelOut_5arcmin_var_import)
head(VarImport_w)


##bio 5
dom_bio05_VarImport<-VarImport[which(VarImport$Var1 == "ch_bio05_agg"), ]
dom_bio05_VarImport<-cbind(dom_bio05_VarImport, "domesticated")
names(dom_bio05_VarImport)[6]<-c("Enset")

wild_bio05_VarImport<-VarImport_w[which(VarImport_w$Var1 == "ch_bio05_agg"), ]
wild_bio05_VarImport<-cbind(wild_bio05_VarImport, "wild")
names(wild_bio05_VarImport)[6]<-c("Enset")

bio05_VarImport<-rbind(dom_bio05_VarImport, wild_bio05_VarImport)

write.csv(bio05_VarImport,"data/bio05_VarImport.csv" )

##bio 12
dom_bio12_VarImport<-VarImport[which(VarImport$Var1 == "ch_bio12_agg"), ]
dom_bio12_VarImport<-cbind(dom_bio12_VarImport, "domesticated")
names(dom_bio12_VarImport)[6]<-c("Enset")

wild_bio12_VarImport<-VarImport_w[which(VarImport_w$Var1 == "ch_bio12_agg"), ]
wild_bio12_VarImport<-cbind(wild_bio12_VarImport, "wild")
names(wild_bio12_VarImport)[6]<-c("Enset")

bio12_VarImport<-rbind(dom_bio12_VarImport, wild_bio12_VarImport)

write.csv(bio12_VarImport,"data/bio12_VarImport.csv" )

##bio 17
dom_bio17_VarImport<-VarImport[which(VarImport$Var1 == "ch_bio17_agg"), ]
dom_bio17_VarImport<-cbind(dom_bio17_VarImport, "domesticated")
names(dom_bio17_VarImport)[6]<-c("Enset")

wild_bio17_VarImport<-VarImport_w[which(VarImport_w$Var1 == "ch_bio17_agg"), ]
wild_bio17_VarImport<-cbind(wild_bio17_VarImport, "wild")
names(wild_bio17_VarImport)[6]<-c("Enset")

bio17_VarImport<-rbind(dom_bio17_VarImport, wild_bio17_VarImport)

write.csv(bio17_VarImport,"data/bio17_VarImport.csv" )

####plotting####
##getting df s
bio05_VarImport<-read.csv("data/bio05_VarImport.csv")
bio12_VarImport<-read.csv("data/bio12_VarImport.csv")
bio17_VarImport<-read.csv("data/bio17_VarImport.csv")

bio05_VarImport$Var1<-"Bio 05"
bio12_VarImport$Var1<-"Bio 12"
bio17_VarImport$Var1<-"Bio 17"

bio_VarImport<- rbind(bio05_VarImport,bio12_VarImport, bio17_VarImport)

dom_bio_VarImport<- bio_VarImport[bio_VarImport$Enset== "domesticated",]

wild_bio_VarImport<- bio_VarImport[bio_VarImport$Enset== "wild",]

VarImport_dom_boxplot<-ggplot(dom_bio_VarImport, aes(x = Var1, y = value)) +
  geom_boxplot(size = 0.8, colour=c("black"), fill= "chartreuse4")+
  ylim(c(0, 1))+
  labs(y="variable importance", x="")+
  theme(
    axis.text = element_text(size = 12),
    axis.title = element_text(size = 13),
    panel.border = element_rect(size = 1, fill = NA),
    panel.grid.major = element_line(linetype = 2, color = F, size = 0.5),
    panel.background = element_rect(fill = FALSE, color= "black"))

VarImport_wild_boxplot<-ggplot(wild_bio_VarImport, aes(x = Var1, y = value)) +
  geom_boxplot(size = 0.8, colour=c("black"), fill= "deeppink4")+
  ylim(c(0, 1))+
  labs(y="variable importance", x="")+
  theme(
    axis.text = element_text(size = 12),
    axis.title = element_text(size = 13),
    panel.border = element_rect(size = 1, fill = NA),
    panel.grid.major = element_line(linetype = 2, color = F, size = 0.5),
    panel.background = element_rect(fill = FALSE, color= "black"))


png(file=paste0("enset", "_comparison", "varImport", ".", "png"), width = 600, height = 300)
multiplot(VarImport_dom_boxplot, VarImport_wild_boxplot, cols=2)
dev.off()


                            ######## Boxplots ecological niche for comparision domesticated vs. wild########
####preparation of data####

#get raster files of bioclim variables
ch_bio05_5arcmin_study_reg<-raster("PATH/SDM/R/plots_new_clean/data/ch_bio05_5arcmin_study_reg.tif")
ch_bio12_5arcmin_study_reg<-raster("PATH/SDM/R/plots_new_clean/data/ch_bio12_5arcmin_study_reg.tif")
ch_bio17_5arcmin_study_reg<-raster("PATH/SDM/R/plots_new_clean/data/ch_bio17_5arcmin_study_reg.tif")

####load presences ###
wild_sample_90<-read.csv("data/wild_sample_90.csv")
wild_sample_90_xy<-cbind(wild_sample_90$x,wild_sample_90$y)
ch_bio_wild_points<-extract(ch_bio_5arcmin_study_reg,wild_sample_90_xy, df=TRUE)
enst_dom_sample2<-read.csv("data/enset_dom_sample2.csv")


#do ttest
t.test(ch_bio_wild_points$ch_bio05_5arcmin_study_reg, enst_dom_sample2$ch_bio05)
t.test(ch_bio_wild_points$ch_bio12_5arcmin_study_reg, enst_dom_sample2$ch_bio12)
t.test(ch_bio_wild_points$ch_bio17_5arcmin_study_reg, enst_dom_sample2$ch_bio17)

####prepare df###
enset_dom_points_bp<-data.frame(cbind("enset" = "domesticated",
                            "Bio05" = as.numeric(enst_dom_sample2$ch_bio05),
                           "Bio12" = as.numeric(enst_dom_sample2$ch_bio12),
                           "Bio17" = as.numeric(enst_dom_sample2$ch_bio17)))

enset_dom_points_bp<-data.frame(cbind(enst_dom_sample2$ch_bio05,
                                      enst_dom_sample2$ch_bio12,
                                      enst_dom_sample2$ch_bio17))
enset_dom_points_bp<-cbind("enset" = "domesticated",
                           enset_dom_points_bp)
names(enset_dom_points_bp)[2:4]<- c("Bio05","Bio12","Bio17")

enset_wild_points_bp<-data.frame(cbind("enset" = "wild",ch_bio_wild_points[,2:4]))
names(enset_wild_points_bp)[2:4]<- c("Bio05","Bio12","Bio17")

enset_points_bp<-rbind(enset_dom_points_bp, enset_wild_points_bp)
enset_points_bp$Bio05<-enset_points_bp$Bio05/10

####plotting####
niche_bio05_boxplot<-ggplot(enset_points_bp, aes(x = enset, y = Bio05)) +
  geom_boxplot(size = 0.8, colour=c("black"), fill = c("chartreuse4", "deeppink4"))+
  labs(y="Bio 5", x="")+
  theme(
    axis.text = element_text(size = 12),
    axis.title = element_text(size = 13),
    panel.border = element_rect(size = 1, fill = NA),
    panel.grid.major = element_line(linetype = 2, color = F, size = 0.5),
    panel.background = element_rect(fill = FALSE, color= "black")
  )

niche_bio12_boxplot<-ggplot(enset_points_bp, aes(x = enset, y = Bio12)) +
  geom_boxplot(size = 0.8, colour=c("black"), fill = c("chartreuse4", "deeppink4"))+
  ylim(c(0, 4000))+
  labs(y="Bio 12", x="")+
  theme(
    axis.text = element_text(size = 12),
    axis.title = element_text(size = 13),
    panel.border = element_rect(size = 1, fill = NA),
    panel.grid.major = element_line(linetype = 2, color = F, size = 0.5),
    panel.background = element_rect(fill = FALSE, color= "black")
  )


niche_bio17_boxplot<-ggplot(enset_points_bp, aes(x = enset, y = Bio17)) +
  geom_boxplot(size = 0.8, colour=c("black"), fill = c("chartreuse4", "deeppink4"))+
  ylim(c(0, 400))+
  labs(y="Bio 17", x="")+
  theme(
    axis.text = element_text(size = 12),
    axis.title = element_text(size = 13),
    panel.border = element_rect(size = 1, fill = NA),
    panel.grid.major = element_line(linetype = 2, color = F, size = 0.5),
    panel.background = element_rect(fill = FALSE, color= "black")
  )

png(file=paste0("enset", "_comparison", "variables_points", ".", "png"), width = 600, height = 300)
multiplot(niche_bio05_boxplot, niche_bio12_boxplot, niche_bio17_boxplot, cols=3)
dev.off()



                                  ### PCA ecological niche ###

#binary suitability
ef_dom_rr60_5arcmin_EMwmeanByTSSbin<-raster("data/proj_current.dom_rr60_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")
ef_wild2_rr63_5arcmin_EMwmeanByTSSbin<-raster("data/proj_current.wild2_rr63_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")

#bioclim variables
ch_bio05_5arcmin_study_reg<-raster("data/ch_bio05_5arcmin_study_reg.tif")
ch_bio12_5arcmin_study_reg<-raster("data/ch_bio12_5arcmin_study_reg.tif")
ch_bio17_5arcmin_study_reg<-raster("data/ch_bio17_5arcmin_study_reg.tif")

ch_bio_5arcmin_study_reg <- stack(ch_bio05_5arcmin_study_reg, 
                                  ch_bio12_5arcmin_study_reg, 
                                  ch_bio17_5arcmin_study_reg)

writeRaster(ch_bio_5arcmin_study_reg,"data/ch_bio_5arcmin_study_reg")


ecol_niche<-stack(ch_bio_5arcmin_study_reg, ef_dom_rr60_5arcmin_EMwmeanByTSSbin, ef_wild2_rr63_5arcmin_EMwmeanByTSSbin)


###### ecological niche with ecospat
ecol_niche<-na.omit(ecol_niche)
ecol_niche_vals<-values(ecol_niche)
ecol_niche_vals<-na.omit(ecol_niche_vals)
ecol_niche_vals<-data.frame(ecol_niche_vals)
write.csv(ecol_niche_vals,"data/ecol_niche_vals.csv")
ecol_niche_vals<-read.csv("data/ecol_niche_vals.csv")
names(ecol_niche_vals)[1:3]<-c("Bio5", "Bio12", "Bio17")
#pca
ecol_niche_pca<-dudi.pca(ecol_niche_vals[,1:3],center=TRUE,scannf = FALSE,nf=2)
#create df of wild and domestic occ in ecol space
ecol_niche_pca_backg<-data.frame(ecol_niche_pca$li,ecol_niche_vals$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.1,ecol_niche_vals$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.2)
dom_niche_pca<-ecol_niche_pca_backg[ which(ecol_niche_pca_backg[,3]==1), ]
wild_niche_pca<-ecol_niche_pca_backg[ which(ecol_niche_pca_backg[,4]==1), ]

#niche grids
dom_niche_grid<-ecospat.grid.clim.dyn(ecol_niche_pca_backg[,1:2],ecol_niche_pca_backg[,1:2],dom_niche_pca[,1:2],R=100,th.sp=0.0, th.env=0.005)
wild_niche_grid<-ecospat.grid.clim.dyn(ecol_niche_pca_backg[,1:2],ecol_niche_pca_backg[,1:2],wild_niche_pca[,1:2],R=100,th.sp=0.0, th.env=0.005)


col_vec_wild = c("#8b0a5000","deeppink4")
col_fun_wild = colorRampPalette(col_vec_wild, alpha=TRUE)


col_vec_dom = c("#458b0000","chartreuse4")
col_fun_dom = colorRampPalette(col_vec_dom, alpha=TRUE)



niche.overlap<-ecospat.niche.overlap (wild_niche_grid, dom_niche_grid,cor=FALSE)
nichedyn.index<-ecospat.niche.dyn.index(wild_niche_grid, dom_niche_grid, intersection=0.005)
niche.idices<-cbind(niche.overlap$D,niche.overlap$I,nichedyn.index$dynamic.index.w)

niche_eqivalency<-ecospat.niche.equivalency.test (dom_niche_grid, wild_niche_grid,5, ncores = 1, alternative = "greater")

ecospat.plot.overlap.test(niche_eqivalency,type="D",title="Niche overlap Test")


###plot niches ###

#adjusted ecospat.plot.niche functions
ecospat.plot.niche2<- function (z, y,  title = "", name.axis1 = "Axis 1", name.axis2 = "Axis 2", 
                                cor = FALSE) 
{
  if (is.null(z$y)) {
    R <- length(z$x)
    x <- z$x
    xx <- sort(rep(1:length(x), 2))
    if (cor == FALSE) 
      y1 <- z$z.uncor/max(z$z.uncor)
    if (cor == TRUE) 
      y1 <- z$z.cor/max(z$z.cor)
    Y1 <- z$Z/max(z$Z)
    yy1 <- sort(rep(1:length(y1), 2))[-c(1:2, length(y1) * 
                                           2)]
    YY1 <- sort(rep(1:length(Y1), 2))[-c(1:2, length(Y1) * 
                                           2)]
    plot(x, y1, type = "n", xlab = name.axis1, ylab = "density of occurrence")
    polygon(x[xx], c(0, y1[yy1], 0, 0), col = "grey")
    lines(x[xx], c(0, Y1[YY1], 0, 0))
  }
  if (!is.null(z$y)) {
    if (cor == FALSE) 
      image(x = z$x, y = z$y, z = t(as.matrix(z$z.uncor))[, 
                                                          nrow(as.matrix(z$z.uncor)):1], col = col_fun_wild(100), 
            zlim = c(1e-06, cellStats(z$z.uncor, "max")), 
            xlab = name.axis1, ylab = name.axis2)
    if (cor == TRUE) 
      image(x = z$x, y = z$y, z = t(as.matrix(z$z.uncor))[, 
                                                          nrow(as.matrix(z$z.uncor)):1], col = col_fun_wild(100), 
            zlim = c(1e-06, cellStats(z$z.cor, "max")), 
            xlab = name.axis1, ylab = name.axis2)
    z$Z <- t(as.matrix(z$Z))[, nrow(as.matrix(z$Z)):1]
    contour(x = z$x, y = z$y, z$Z, add = TRUE, levels = quantile(z$Z[z$Z > 
                                                                       0], c(0, 0.5)), drawlabels = FALSE, lty = c(1, 2))
  }
  title(title)
}

ecospat.plot.niche3<- function (z, title = "", name.axis1 = "Axis 1", name.axis2 = "Axis 2", 
                                cor = FALSE) 
{
  if (is.null(z$y)) {
    R <- length(z$x)
    x <- z$x
    xx <- sort(rep(1:length(x), 2))
    if (cor == FALSE) 
      y1 <- z$z.uncor/max(z$z.uncor)
    if (cor == TRUE) 
      y1 <- z$z.cor/max(z$z.cor)
    Y1 <- z$Z/max(z$Z)
    yy1 <- sort(rep(1:length(y1), 2))[-c(1:2, length(y1) * 
                                           2)]
    YY1 <- sort(rep(1:length(Y1), 2))[-c(1:2, length(Y1) * 
                                           2)]
    plot(x, y1, type = "n", xlab = name.axis1, ylab = "density of occurrence")
    polygon(x[xx], c(0, y1[yy1], 0, 0), col = "grey")
    lines(x[xx], c(0, Y1[YY1], 0, 0))
  }
  if (!is.null(z$y)) {
    if (cor == FALSE) 
      image(x = z$x, y = z$y, z = t(as.matrix(z$z.uncor))[, 
                                                          nrow(as.matrix(z$z.uncor)):1], col = col_fun_dom(100), 
            zlim = c(1e-06, cellStats(z$z.uncor, "max")), 
            xlab = name.axis1, ylab = name.axis2)
    if (cor == TRUE) 
      image(x = z$x, y = z$y, z = t(as.matrix(z$z.uncor))[, 
                                                          nrow(as.matrix(z$z.uncor)):1], col = col_fun_dom(100), 
            zlim = c(1e-06, cellStats(z$z.cor, "max")), 
            xlab = name.axis1, ylab = name.axis2)
    z$Z <- t(as.matrix(z$Z))[, nrow(as.matrix(z$Z)):1]
    contour(x = z$x, y = z$y, z$Z, add = TRUE, levels = quantile(z$Z[z$Z > 
                                                                       0], c(0, 0.5)), drawlabels = FALSE, lty = c(1, 2))
  }
  title(title)
}




png(file=paste0("enset", "_wild", "ecospat.niche", ".", "png"), width = 400, height = 400)
wild_ecospat_niche2<-ecospat.plot.niche2(wild_niche_grid,title="",name.axis1 = "PC1",name.axis2 = "PC2", cor = FALSE)
plot(wild_niche_grid$z.uncor, col=col_fun_wild(100), add=FALSE,legend.only=TRUE, legend=TRUE, smallplot=c(0.83,0.84,0.55,0.78),legend.args= list(text=c("occ. density\n wild"), font=2,cex=1,side=3))
dev.off()

png(file=paste0("enset", "_dom", "ecospat.niche", ".", "png"), width = 400, height = 400)
dom_ecospat_niche2<-ecospat.plot.niche3(dom_niche_grid,title="",name.axis1 = "PC1",name.axis2 = "PC2", cor = FALSE)
plot(dom_niche_grid$z.uncor, col=col_fun_dom(100), add=FALSE, legend=TRUE,legend.only=TRUE, smallplot=c(0.83,0.84,0.55,0.78), legend.args= list(text=c("occ. density\n dom"), font=2,cex=1,side=3))
dev.off()

png(file=paste0("enset", "_comparison", "ecospat.niche", ".", "png"), width = 400, height = 400)
wild_ecospat_niche2<-ecospat.plot.niche2(wild_niche_grid,title="",name.axis1 = "PC1",name.axis2 = "PC2", cor = FALSE)
plot(dom_niche_grid$z.uncor, col=col_fun_dom(100), add=TRUE, legend=F)
dev.off()

png(file=paste0("enset", "_niche_dyn", "ecospat.niche", ".", "png"), width = 300, height = 300)
niche.dyn<-ecospat.plot.niche.dyn (wild_niche_grid, dom_niche_grid,title="", quant=0.0,name.axis1= "PC1", name.axis2= "PC2",  colz1=t_col("deeppink4",percent = 0,name=NULL), colz2=t_col("chartreuse4",percent = 0,name=NULL),colinter=t_col("darkolivegreen",percent = 0,name=NULL), colZ1="blue", colZ2=NA,interest= 2)
dev.off()

png(file=paste0("enset", "_contrib", "ecospat.niche", ".", "png"), width = 400, height = 400)
s.corcircle(ecol_niche_pca$co, fullcircle = T, grid=F, clabel=1.5, sub="PC1 = 67.68%, PC2 = 19.69%", csub=1.5, possub = "bottomright")
dev.off()





                              #### Boyce plots####

###domesticated enset###

####data preparation####
##read projections, reference area
ef_rr60_5arcmin_EMwmeanByTSS<-raster("data/proj_current.dom_rr60_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
boundary_reference_agroclim<-readOGR("data/agroclim_eth2.shp")

enset_dom_sample2<-read.csv("data/enset_dom_sample2.csv")
enset_dom_sample60<-read.csv("data/enset_dom_sample60.csv")


e_dom_eval_sample60<-setDT(enset_dom_sample2)[!X%in%enset_dom_sample60$X]
e_dom_eval_sample60<-ddply(e_dom_eval_sample60,.(Cluster),function(x) x[sample(nrow(x),1),])
write.csv(e_dom_eval_sample60, "data/e_dom_eval_sample60.csv")

ef_rr60_5arcmin_EMwmeanByTSS_vals<-values(ef_rr60_5arcmin_EMwmeanByTSS)

probabilities_rr_ref<-mask(ef_rr60_5arcmin_EMwmeanByTSS, boundary_reference_agroclim)
probabilities_rr_ref_cr<-crop(ef_rr60_5arcmin_EMwmeanByTSS, boundary_reference_agroclim)

cbi_rr_oc<-cbind(e_dom_eval_sample60$Longitude,e_dom_eval_sample60$Latitude)

cbi_rr_random<-randomPoints(mask= probabilities_rr_ref_cr, n=18602, p= cbi_rr_oc, ext= boundary_reference_agroclim, cellnumbers = FALSE, lonlatCorrection = TRUE)

cbi_rr_random_val<-extract(probabilities_rr_ref_cr,cbi_rr_random, df=TRUE)
cbi_rr_random_val<-cbind(cbi_rr_random,cbi_rr_random_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData,0)

cbi_rr_oc_val<-extract(probabilities_rr_ref_cr,cbi_rr_oc, df=TRUE)
cbi_rr_oc_val<-cbind(cbi_rr_oc,cbi_rr_oc_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData,1)

cbi_rr_obs<-rbind(cbi_rr_oc_val, cbi_rr_random_val)

colnames(cbi_rr_obs)[3:4]<-c("pres","obs")

cbi_rr_obs<-data.frame(cbi_rr_obs)
write.csv(cbi_rr_obs, "data/cbi_rr_obs.csv")

####plotting CBI for domesticated enset#### 
cbi_rr_obs<-read.csv("data/cbi_rr_obs.csv")

t_rr_obs <- (cbi_rr_obs$pres [which(cbi_rr_obs$obs==1)])
t_rr_boyce <- ecospat.boyce (fit = cbi_rr_obs$pres , t_rr_obs, nclass=0,
                             window.w="default", res=100, PEplot=T)
t_rr_boyce$Spearman.cor

####wild enset 2(presences across study area) reference area####
####prepare data####
##read projections, reference area extent and evaluation data
wild2_rr63_5arcmin_EMwmeanByTSS<-raster("Ensete.ventricosum/proj_current.wild2_rr63_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
boundary_reference_agroclim_w2<-readOGR("data/background_w2_agroclim_boundary.shp")

e_wild2_eval_sample63<-read.csv("C:/data/wild2_sample_eval63.csv")
e_wild2_eval_sample63_xy<-cbind(e_wild2_eval_sample63$x,e_wild2_eval_sample63$y)

#generate random points
boyce_w2_random_reference<-randomPoints(mask= wild2_rr63_5arcmin_EMwmeanByTSS, n=150000, p= e_wild2_eval_sample63_xy, ext= boundary_reference_agroclim_w2, cellnumbers = FALSE, lonlatCorrection = TRUE)

#backgrund values
boyce_w2_random_reference_val<-extract(wild2_rr63_5arcmin_EMwmeanByTSS,boyce_w2_random_reference, df=TRUE)
boyce_w2_random_reference_val<-cbind(boyce_w2_random_reference,boyce_w2_random_reference_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData,0)

#presence values
boyce_w2_reference_oc_val<-extract(wild2_rr63_5arcmin_EMwmeanByTSS,e_wild2_eval_sample63_xy, df=TRUE)
boyce_w2_reference_oc_val<-cbind(e_wild2_eval_sample63_xy,boyce_w2_reference_oc_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData,1)

boyce_w2_reference_obs<-rbind(boyce_w2_reference_oc_val, boyce_w2_random_reference_val)

colnames(boyce_w2_reference_obs)[3:4]<-c("pres","obs")

boyce_w2_reference_obs<-data.frame(boyce_w2_reference_obs)

write.csv(boyce_w2_reference_obs, "data/boyce_w2_reference_obs.csv")

####plot Boyce index for wild enset projections in reference area####
boyce_w2_reference_obs<-read.csv("data/boyce_w2_reference_obs.csv")

obs_w2_reference <- (boyce_w2_reference_obs$pres [which(boyce_w2_reference_obs$obs==1)])
boyce_w2_reference <- ecospat.boyce (fit = boyce_w2_reference_obs$pres , obs_w2_reference, nclass=0,
                         window.w="default", res=100, PEplot=T)
boyce_w2_reference$Spearman.cor

#### Continous boyce index (CBI) plot wild 2 TRANSFER####
####prepare data####
#read projections, transfer area extent and evaluation data
wild2_rr63_5arcmin_EMwmeanByTSS<-raster("data/proj_current.wild2_rr63_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
boundary_transfer_agroclim<-readOGR("data/transfer_area_agroclim2.shp")
wild2_rr63_5arcmin_EMwmeanByTSS_transfer<-mask(wild2_rr63_5arcmin_EMwmeanByTSS, boundary_transfer_agroclim)
wild2_rr63_5arcmin_EMwmeanByTSS_transfer<-crop(wild2_rr63_5arcmin_EMwmeanByTSS_transfer, boundary_transfer_agroclim)

#generate random points
boyce_w2_random_transfer<-randomPoints(mask= wild2_rr63_5arcmin_EMwmeanByTSS_transfer, n=150000, p= e_wild2_eval_sample63_xy, ext= boundary_transfer_agroclim, cellnumbers = FALSE, lonlatCorrection = TRUE)

#backgrund values
boyce_w2_random_transfer_val<-extract(wild2_rr63_5arcmin_EMwmeanByTSS_transfer,boyce_w2_random_transfer, df=TRUE)
boyce_w2_random_transfer_val<-cbind(boyce_w2_random_transfer,boyce_w2_random_transfer_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData,0)

#presence values
boyce_w2_transfer_oc_val<-extract(wild2_rr63_5arcmin_EMwmeanByTSS_transfer,e_wild2_eval_sample63_xy, df=TRUE)
boyce_w2_transfer_oc_val<-cbind(e_wild2_eval_sample63_xy,boyce_w2_transfer_oc_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData,1)
boyce_w2_transfer_oc_val<-na.omit(boyce_w2_transfer_oc_val)

boyce_w2_transfer_obs<-rbind(boyce_w2_transfer_oc_val, boyce_w2_random_transfer_val)

colnames(boyce_w2_transfer_obs)[3:4]<-c("pres","obs")

boyce_w2_transfer_obs<-data.frame(boyce_w2_transfer_obs)

write.csv(boyce_w2_transfer_obs, "data/boyce_w2_transfer_obs.csv")

####plot Boyce index for wild enset 2 projections in transfer space####
boyce_w2_transfer_obs<-read.csv("data/boyce_w2_transfer_obs.csv")

obs_w2_transfer <- (boyce_w2_transfer_obs$pres [which(boyce_w2_transfer_obs$obs==1)])
boyce_w2_transfer <- ecospat.boyce (fit = boyce_w2_transfer_obs$pres , obs_w2_transfer, nclass=0,
                         window.w="default", res=100, PEplot=T)
boyce_w2_transfer$Spearman.cor




### Variability between model projections vs. predicted suitability
#### load predictions and cv####
#dom
ef_dom_rr60_5arcmin_EMwmeanByTSS<-raster("data/proj_current.dom_rr60_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
ef_dom_rr60_5arcmin_EMcvByTSS<-raster("data/proj_current.dom_rr60_5arcmin/individual_projections/Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData.img")

ef_dom_rr60_5arcmin_cv_wmean<-stack(ef_dom_rr60_5arcmin_EMwmeanByTSS, ef_dom_rr60_5arcmin_EMcvByTSS)

cv_vs_wmean<-randomPoints(mask= ef_dom_rr60_5arcmin_EMwmeanByTSS, n=4000, cellnumbers = FALSE, lonlatCorrection = TRUE)

cv_vs_wmean<-extract(ef_dom_rr60_5arcmin_cv_wmean,cv_vs_wmean, df=TRUE)

cv_vs_wmean$Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData<-cv_vs_wmean$Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData/1000
cv_vs_wmean$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData<-cv_vs_wmean$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData/1000

cv_vs_wmean_plot<-ggplot(cv_vs_wmean, aes(y = Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData, x = Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData))+
  geom_point()+
  labs(x = "Suitability", y = "Uncertainty")+
  ggtitle("Current")


#wild1
ef_wild_rr_5arcmin_EMwmeanByTSS<-raster("data/proj_current.wild_rr_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
ef_wild_rr_5arcmin_EMcvByTSS<-raster("data/proj_current.wild_rr_5arcmin/individual_projections/Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData.img")

ef_wild_rr_5arcmin_cv_wmean<-stack(ef_wild_rr_5arcmin_EMwmeanByTSS, ef_wild_rr_5arcmin_EMcvByTSS)

wild_rr_cv_vs_wmean<-randomPoints(mask= ef_wild_rr_5arcmin_EMwmeanByTSS, n=4000, cellnumbers = FALSE, lonlatCorrection = TRUE)

wild_rr_cv_vs_wmean<-extract(ef_wild_rr_5arcmin_cv_wmean,wild_rr_cv_vs_wmean, df=TRUE)

wild_rr_cv_vs_wmean$Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData<-wild_rr_cv_vs_wmean$Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData/1000
wild_rr_cv_vs_wmean$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData<-wild_rr_cv_vs_wmean$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData/1000

wild_rr_cv_vs_wmean_plot<-ggplot(wild_rr_cv_vs_wmean, aes(y = Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData, x = Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData),colour="green", size=3)+
  geom_point()+
  labs(x = "Suitability", y = "Uncertainty")+
  ggtitle("Current")

#wild2
ef_wild2_rr63_5arcmin_EMwmeanByTSS<-raster("data/proj_current.wild2_rr63_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
ef_wild2_rr63_5arcmin_EMcvByTSS<-raster("data/proj_current.wild2_rr63_5arcmin/individual_projections/Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData.img")

ef_wild2_rr63_5arcmin_cv_wmean<-stack(ef_wild2_rr63_5arcmin_EMwmeanByTSS, ef_wild2_rr63_5arcmin_EMcvByTSS)

wild2_rr63_cv_vs_wmean<-randomPoints(mask= ef_wild2_rr63_5arcmin_EMwmeanByTSS, n=4000, cellnumbers = FALSE, lonlatCorrection = TRUE)

wild2_rr63_cv_vs_wmean<-extract(ef_wild2_rr63_5arcmin_cv_wmean,wild2_rr63_cv_vs_wmean, df=TRUE)

wild2_rr63_cv_vs_wmean$Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData<-wild2_rr63_cv_vs_wmean$Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData/1000
wild2_rr63_cv_vs_wmean$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData<-wild2_rr63_cv_vs_wmean$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData/1000

wild2_rr63_cv_vs_wmean_plot<-ggplot(wild2_rr63_cv_vs_wmean, aes(y = Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData, x = Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData),colour="green", size=3)+
  geom_point()+
  geom_pint(data=cv_vs_wmean, aes(y = Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData, x = Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData),colour="yellow", size=3)+
  labs(x = "Suitability", y = "Uncertainty")+
  ggtitle("Current")

wild_dom_cv_vs_wmean_plot<-ggplot(wild2_rr63_cv_vs_wmean, aes(y = Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData, x = Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData))+
  geom_point(colour="deeppink4", alpha= 0.5, size=1.5)+
  geom_point(data=cv_vs_wmean, aes(y = Ensete.ventricosum_EMcvByTSS_mergedAlgo_mergedRun_mergedData, x = Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData),colour="chartreuse4", alpha= 0.5, legend= T,size=1.5)+
  theme(
    panel.border = element_rect(size = 1, fill = NA),
    panel.grid.major = element_line(linetype = 2, color = F, size = 0.5),
    panel.background = element_rect(fill = FALSE, color= "black"),
    legend.position = "bottom",
    axis.title=element_text(size=14),
    legend.text=element_text(size=13.85)
  )+
  labs(x = "Suitability", y = "Uncertainty")

plot(wild_dom_cv_vs_wmean_plot)
###




##### determine thresholds for binary representation of indication of abundance #####

####data preparation####
##read projections, reference area
ef_rr60_5arcmin_EMwmeanByTSS<-raster("data/proj_current.dom_rr60_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5<-raster("PATH/SDM/R/Ensete.ventricosum/proj_dom_rr60_5arcmin_2050.rcp4.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5<-raster("PATH/SDM/R/Ensete.ventricosum/proj_dom_rr60_5arcmin_2050.rcp8.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5<-raster("PATH/SDM/R/Ensete.ventricosum/proj_dom_rr60_5arcmin_2070.rcp4.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")
ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5<-raster("PATH/SDM/R/Ensete.ventricosum/proj_dom_rr60_5arcmin_2070.rcp8.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData.img")

ef_rr60_5arcmin_EMwmeanByTSS_TSSbin<-raster("data/proj_current.dom_rr60_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")
ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin<-raster("PATH/SDM/R/Ensete.ventricosum/proj_dom_rr60_5arcmin_2050.rcp4.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")
ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin<-raster("PATH/SDM/R/Ensete.ventricosum/proj_dom_rr60_5arcmin_2050.rcp8.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")
ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin<-raster("PATH/SDM/R/Ensete.ventricosum/proj_dom_rr60_5arcmin_2070.rcp4.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")
ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin<-raster("PATH/SDM/R/Ensete.ventricosum/proj_dom_rr60_5arcmin_2070.rcp8.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")

wild_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin<-raster("data/proj_current.wild2_rr63_5arcmin/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")
wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin<-raster("PATH/SDM/R/Ensete.ventricosum/proj_wild2_rr63_5arcmin_2050.rcp4.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")
wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin<-raster("PATH/SDM/R/Ensete.ventricosum/proj_wild2_rr63_5arcmin_2050.rcp8.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")
wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin<-raster("PATH/SDM/R/Ensete.ventricosum/proj_wild2_rr63_5arcmin_2070.rcp4.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")
wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin<-raster("PATH/SDM/R/Ensete.ventricosum/proj_wild2_rr63_5arcmin_2070.rcp8.5/individual_projections/Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData_TSSbin.img")

wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin<-stack(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin,wild_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin)
wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin<-stack(ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin,wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin)
wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin<-stack(ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin,wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin)
wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin<-stack(ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin,wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin)
wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin<-stack(ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin,wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin)

wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin<-calc(wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin,fun=max, na.rm=T)
wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin<-calc(wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin,fun=max, na.rm=T)
wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin<-calc(wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin,fun=max, na.rm=T)
wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin<-calc(wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin,fun=max, na.rm=T)
wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin<-calc(wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin,fun=max, na.rm=T)

wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack<-stack(wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin,
                                                    wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin,
                                                    wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin,
                                                    wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin,
                                                    wild_dom_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin)

boundary_reference_agroclim<-readOGR("data/agroclim_eth2.shp")

enset_abundance<-read.csv("data/ALL_domesticated_enset_olef.csv")
enset_abundance<-na.omit(enset_abundance)
enset_abundance_xy<-cbind(enset_abundance[,2], enset_abundance[,1])
enset_abundance_val<-extract(ef_rr60_5arcmin_EMwmeanByTSS,enset_abundance_xy, df=TRUE)
enset_abundance_val<-cbind(enset_abundance,enset_abundance_val)
enset_abundance_val2<-enset_abundance_val[!enset_abundance_val[,4]=="flowering",]

enset_abundance_rare_val<-enset_abundance_val[enset_abundance_val[,4]=="rare",]
enset_abundance_moderate_rare_val<-enset_abundance_val[enset_abundance_val[,4]=="moderate_to_rare",]
enset_abundance_moderate_val<-enset_abundance_val[enset_abundance_val[,4]=="moderate",]
enset_abundance_abundant_val<-enset_abundance_val[enset_abundance_val[,4]== "abundant",]
enset_abundance_abundant_mono_val<-enset_abundance_val[enset_abundance_val[,4]== "abundant_mono",]
enset_abundance_abundant_mixed_val<-enset_abundance_val[enset_abundance_val[,4]== "abundant_mixed",]
enset_abundance_abundant_all_val<- rbind(enset_abundance_abundant_val,enset_abundance_abundant_mono_val,enset_abundance_abundant_mixed_val )
enset_abundance_abundant_moderate_val<- rbind(enset_abundance_abundant_val,enset_abundance_abundant_mono_val,enset_abundance_abundant_mixed_val,enset_abundance_moderate_val )
enset_abundance_r_m_a_val<-rbind(enset_abundance_rare_val, enset_abundance_moderate_val, enset_abundance_abundant_all_val )
enset_abundance_r_m_a_val$Type_detailed[enset_abundance_r_m_a_val$Type_detailed%in% c("abundant_mono","abundant_mixed")] <- "abundant"
enset_abundance_am_r_val<-enset_abundance_r_m_a_val$Type_detailed[enset_abundance_r_m_a_val$Type_detailed%in% c("abundant_mono","abundant_mixed", "moderate")] <- "abundant"

levels(enset_abundance_r_m_a_val$Type_detailed)
enset_abundance_r_m_a_val<-droplevels(enset_abundance_r_m_a_val)
enset_abundance_r_m_a_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData<-enset_abundance_r_m_a_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData/1000
plot(enset_abundance_r_m_a_val$Type_detailed,enset_abundance_r_m_a_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData)

ggplot(enset_abundance_r_m_a_val, aes(x = Type_detailed, y = Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData)) +
  geom_boxplot()+
  ylim(c(0, 1))+
  labs(y="suitability score", x="abundance in farm system")+
  theme(
    panel.border = element_rect(size = 1, fill = NA),
    panel.grid.major = element_line(linetype = 0, color = "black", size = 0),
    panel.background = element_rect(fill = FALSE, color= "black")
  )

ggplot(enset_abundance_am_r_val, aes(Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, fill = Type_detailed)) + geom_density(alpha = 0.2)

quantile(enset_abundance_abundant_all_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, probs=c(0.05, 0.25, 0.5, 0.90, 0.95),na.rm = T)
quantile(enset_abundance_abundant_mixed_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, probs=c(0.05, 0.25, 0.5, 0.90, 0.95),na.rm = T)
quantile(enset_abundance_abundant_mono_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, probs=c(0.05,0.25, 0.5, 0.90, 0.95),na.rm = T)
quantile(enset_abundance_abundant_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, probs=c(0.05,0.25, 0.5, 0.90, 0.95),na.rm = T)
quantile(enset_abundance_moderate_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, probs=c(0.05,0.25, 0.5, 0.90, 0.95),na.rm = T)
quantile(enset_abundance_moderate_rare_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, probs=c(0.05,0.25, 0.5, 0.90, 0.95),na.rm = T)
quantile(enset_abundance_rare_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, probs=c(0.05,0.1, 0.25, 0.5, 0.90, 0.95),na.rm = T)
quantile(enset_abundance_val2$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, probs=c(0.05,0.25, 0.5, 0.90, 0.95),na.rm = T)
quantile(enset_abundance_abundant_moderate_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData, probs=c(0.05,0.25, 0.5, 0.90, 0.95),na.rm = T)

ef_rr60_5arcmin_EMwmeanByTSS_abundance<-reclassify(ef_rr60_5arcmin_EMwmeanByTSS, c(-Inf, 366, 0,  366, 567.49, 1, 567.49, Inf, 2))
ef_rr60_5arcmin_EMwmeanByTSS_abundance_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_abundance, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_abundance_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_abundance_nWDPA, spam_cropland_nWDPA_shp)

ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_abundance<-reclassify(ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5, c(-Inf, 366, 0,  366, 567.49, 1, 567.49, Inf, 2))
ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_abundance_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_abundance, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_abundance_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_abundance_nWDPA, spam_cropland_nWDPA_shp)

ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_abundance<-reclassify(ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5, c(-Inf, 366, 0,  366, 567.49, 1, 567.49, Inf, 2))
ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_abundance_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_abundance, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_abundance_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_abundance_nWDPA, spam_cropland_nWDPA_shp)

ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_abundance<-reclassify(ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5, c(-Inf, 366, 0,  366, 567.49, 1, 567.49, Inf, 2))
ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_abundance_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_abundance, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_abundance_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_abundance_nWDPA, spam_cropland_nWDPA_shp)

ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_abundance<-reclassify(ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5, c(-Inf, 366, 0,  366, 567.49, 1, 567.49, Inf, 2))
ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_abundance_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_abundance, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_abundance_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_abundance_nWDPA, spam_cropland_nWDPA_shp)

ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA<-mask(ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin, spam_cropland_nWDPA_shp)
ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA<-crop(ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA, spam_cropland_nWDPA_shp)

wild_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA<-mask(wild_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin, spam_cropland_nWDPA_shp)
wild_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA<-crop(wild_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA, spam_cropland_nWDPA_shp)
wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA<-mask(wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin, spam_cropland_nWDPA_shp)
wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA<-crop(wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA, spam_cropland_nWDPA_shp)
wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA<-mask(wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin, spam_cropland_nWDPA_shp)
wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA<-crop(wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA, spam_cropland_nWDPA_shp)
wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA<-mask(wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin, spam_cropland_nWDPA_shp)
wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA<-crop(wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA, spam_cropland_nWDPA_shp)
wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA<-mask(wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin, spam_cropland_nWDPA_shp)
wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA<-crop(wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA, spam_cropland_nWDPA_shp)


writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_abundance, "data/dom_curr_abundance_class.img")
writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_abundance_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_current_abundance_cropl_spam_nWDPA.tif")

writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_abundance, "data/dom_2050_rcp4.5_abundance_class.tif")
writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_abundance_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2050_rcp45_abundance_cropl_spam_nWDPA.tif")

writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_abundance, "data/dom_2050_rcp8.5_abundance_class.tif")
writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_abundance_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2050_rcp85_abundance_cropl_spam_nWDPA.tif")

writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_abundance, "data/dom_2070_rcp4.5_abundance_class.tif")
writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_abundance_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2070_rcp45_abundance_cropl_spam_nWDPA.tif")

writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_abundance, "data/dom_2070_rcp8.5_abundance_class.tif")
writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_abundance_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2070_rcp85_abundance_cropl_spam_nWDPA.tif")

writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_current_TSSbin_cropl_spam_nWDPA.tif")
writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2050_rcp45_TSSbin_cropl_spam_nWDPA.tif")
writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2050_rcp85_TSSbin_cropl_spam_nWDPA.tif")
writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2070_rcp45_TSSbin_cropl_spam_nWDPA.tif")
writeRaster(ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2070_rcp85_TSSbin_cropl_spam_nWDPA.tif")

writeRaster(wild_ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/wild_rr63_bin_proj_current_TSSbin_cropl_spam_nWDPA.tif")
writeRaster(wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/wild_rr63_bin_proj_2050_rcp45_TSSbin_cropl_spam_nWDPA.tif")
writeRaster(wild_ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/wild_rr63_bin_proj_2050_rcp85_TSSbin_cropl_spam_nWDPA.tif")
writeRaster(wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/wild_rr63_bin_proj_2070_rcp45_TSSbin_cropl_spam_nWDPA.tif")
writeRaster(wild_ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA, "PATH/SDM/GIS/raster/proj_refined/wild_rr63_bin_proj_2070_rcp85_TSSbin_cropl_spam_nWDPA.tif")

ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA<-raster("PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_current_TSSbin_cropl_spam_nWDPA.tif")

ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_curr_core<-mask(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA, cult_curr_core)
ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_curr_core<-crop(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_curr_core, cult_curr_core)

ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_eth<-mask(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA, boundary_ethiopia)
ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_eth<-crop(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_eth, boundary_ethiopia)

ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_eth_vals<-raster::values(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_eth)

ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_vals<-values(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA)
ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_vals<-na.omit(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_vals)
ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_eth_vals<-na.omit(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_eth_vals)

sum(na.omit(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_vals))-sum(na.omit(ef_rr60_5arcmin_EMwmeanByTSS_TSSbin_nWDPA_eth_vals))

t.test(enset_abundance_abundant_moderate_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData,enset_abundance_rare_val$Ensete.ventricosum_EMwmeanByTSS_mergedAlgo_mergedRun_mergedData )

e_dom_eval_sample60<-setDT(enset_dom_sample2)[!X%in%enset_dom_sample60$X]
e_dom_eval_sample60<-ddply(e_dom_eval_sample60,.(Cluster),function(x) x[sample(nrow(x),1),])
write.csv(e_dom_eval_sample60, "data/e_dom_eval_sample60.csv")

ef_rr60_5arcmin_EMwmeanByTSS_vals<-values(ef_rr60_5arcmin_EMwmeanByTSS)

probabilities_rr_ref<-mask(ef_rr60_5arcmin_EMwmeanByTSS, boundary_reference_agroclim)
probabilities_rr_ref_cr<-crop(ef_rr60_5arcmin_EMwmeanByTSS, boundary_reference_agroclim)




##Tables suitability by country

cult_shift_potential<-readOGR("PATH/SDM/GIS/shapes/cult_shift_potential.shp")


Even_bin_proj_comp_ref2<-stack(c(curr ="PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_current_TSSbin_cropl_spam_nWDPA.tif",
                                 curr_w_d =  wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack_cropl_nWDPA$layer.1,
                                 rcp45_2050 ="PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2050_rcp45_TSSbin_cropl_spam_nWDPA.tif",
                                 rcp45_2050_w_d = wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack_cropl_nWDPA$layer.2,
                                 rcp85_2050 ="PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2050_rcp85_TSSbin_cropl_spam_nWDPA.tif",
                                 rcp85_2050_w_d = wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack_cropl_nWDPA$layer.3,
                                 rcp45_2070 ="PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2070_rcp45_TSSbin_cropl_spam_nWDPA.tif",
                                 rcp45_2070_w_d = wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack_cropl_nWDPA$layer.4,
                                 rcp85_2070 ="PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_2070_rcp85_TSSbin_cropl_spam_nWDPA.tif",
                                 rcp85_2070_w_d = wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack_cropl_nWDPA$layer.5
))

Even_bin_proj_comp_ref_cr<-stack(c(curr_cr = crop(mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_current_TSSbin_nWDPA_shp),ef_rr60_5arcmin_EMwmeanByTSS_current_TSSbin_nWDPA_shp),
                                   curr_cr_w_d = crop(mask(crop_area_spam_sum_res, wild_dom_current_TSSbin_nWDPA_shp),wild_dom_current_TSSbin_nWDPA_shp),
                                   rcp45_2050_cr = crop(mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA_shp),ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA_shp),
                                   rcp45_2050_cr_w_d = crop(mask(crop_area_spam_sum_res, wild_dom_2050_4.5_TSSbin_nWDPA_shp),wild_dom_2050_4.5_TSSbin_nWDPA_shp),
                                   rcp85_2050_cr = crop(mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA_shp),ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA_shp),
                                   rcp85_2050_cr_w_d = crop(mask(crop_area_spam_sum_res, wild_dom_2050_8.5_TSSbin_nWDPA_shp),wild_dom_2050_8.5_TSSbin_nWDPA_shp),
                                   rcp45_2070_cr = crop(mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA_shp),ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA_shp),
                                   rcp45_2070_cr_w_d = crop(mask(crop_area_spam_sum_res, wild_dom_2070_4.5_TSSbin_nWDPA_shp),wild_dom_2070_4.5_TSSbin_nWDPA_shp),
                                   rcp85_2070_cr = crop(mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA_shp),ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA_shp),
                                   rcp85_2070_cr_w_d = crop(mask(crop_area_spam_sum_res, wild_dom_2070_8.5_TSSbin_nWDPA_shp),wild_dom_2070_8.5_TSSbin_nWDPA_shp)))


Even_bin_proj_comp_ref_cr<-stack(c(curr_cr = mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_current_TSSbin_nWDPA_shp),
                                   curr_cr_w_d = mask(crop_area_spam_sum_res, wild_dom_current_TSSbin_nWDPA_shp),
                                   rcp45_2050_cr = mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_2050_4.5_TSSbin_nWDPA_shp),
                                   rcp45_2050_cr_w_d = mask(crop_area_spam_sum_res, wild_dom_2050_4.5_TSSbin_nWDPA_shp),
                                   rcp85_2050_cr = mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_2050_8.5_TSSbin_nWDPA_shp),
                                   rcp85_2050_cr_w_d = mask(crop_area_spam_sum_res, wild_dom_2050_8.5_TSSbin_nWDPA_shp),
                                   rcp45_2070_cr = mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_2070_4.5_TSSbin_nWDPA_shp),
                                   rcp45_2070_cr_w_d = mask(crop_area_spam_sum_res, wild_dom_2070_4.5_TSSbin_nWDPA_shp),
                                   rcp85_2070_cr = mask(crop_area_spam_sum_res, ef_rr60_5arcmin_EMwmeanByTSS_2070_8.5_TSSbin_nWDPA_shp),
                                   rcp85_2070_cr_w_d = mask(crop_area_spam_sum_res, wild_dom_2070_8.5_TSSbin_nWDPA_shp)))


suitable_country_ref<-extract(Even_bin_proj_comp_ref,boundary_study_reg,method="simple", fun= "sum", cellnumbers=TRUE, na.rm=TRUE, df=TRUE)

suitable_country_ref<-cbind(boundary_study_reg$NAME_0,suitable_country_ref)

suitable_country_ref2<-extract(Even_bin_proj_comp_ref2,boundary_study_reg,method="simple", fun= "sum", cellnumbers=TRUE, na.rm=TRUE, df=TRUE)
suitable_country_ref2_all_bind<-rbind(sum(suitable_country_ref2_all$ID==1),
                                      sum(suitable_country_ref2_all$ID==2), 
                                      sum(suitable_country_ref2_all$ID==3), 
                                      sum(suitable_country_ref2_all$ID==4),
                                      sum(suitable_country_ref2_all$ID==5),
                                      sum(suitable_country_ref2_all$ID==6),
                                      sum(suitable_country_ref2_all$ID==7),
                                      sum(suitable_country_ref2_all$ID==8),
                                      sum(suitable_country_ref2_all$ID==9),
                                      sum(suitable_country_ref2_all$ID==10),
                                      sum(suitable_country_ref2_all$ID==11),
                                      sum(suitable_country_ref2_all$ID==12),
                                      sum(suitable_country_ref2_all$ID==13),
                                      sum(suitable_country_ref2_all$ID==14),
                                      sum(suitable_country_ref2_all$ID==15),
                                      sum(suitable_country_ref2_all$ID==16),
                                      sum(suitable_country_ref2_all$ID==17),
                                      sum(suitable_country_ref2_all$ID==18))
suitable_country_ref_cr<-extract(Even_bin_proj_comp_ref_cr,boundary_study_reg,method="simple", fun= "sum", cellnumbers=TRUE, na.rm=TRUE, df=TRUE)
suitable_country_ref_cr_sum<-extract(crop_area_spam_sum_res, boundary_study_reg, fun= sum, df=TRUE)
suitable_country_ref2<-cbind(boundary_study_reg$NAME_0,suitable_country_ref2,suitable_country_ref2_all_bind)
suitable_country_ref_cr<-cbind(boundary_study_reg$NAME_0,suitable_country_ref_cr, suitable_country_ref_cr_sum$crop_area_spam_sum)

suitable_country_ref_cr_sum<-extract(crop_area_spam_sum_res, boundary_study_reg, method="simple", fun= "sum", cellnumbers=TRUE, na.rm=TRUE, df=TRUE)

suitable_country_ref_cr_sum<-extract(crop_area_spam_sum_res, boundary_study_reg, fun= sum, df=TRUE)

suitable_country_ref2_all<-extract(Even_bin_proj_comp_ref2$curr,boundary_study_reg,method="simple",cellnumbers=TRUE, na.rm=TRUE, df=TRUE)

suitable_country_ref2<-cbind(suitable_country_ref2[,1:2],suitable_country_ref2[,3:13]*100)
suitable_country_ref_cr<-cbind(suitable_country_ref_cr[,1],suitable_country_ref_cr[,3:13]/100)

suitable_curr_extent_ref<-mask(Even_bin_proj_comp_ref2,cult_curr_core)
suitable_curr_extent_ref<-crop(suitable_curr_extent_ref,cult_curr_core)
suitable_curr_extent_ref_sum<-extract(suitable_curr_extent_ref, cult_curr_core, fun= sum, df=TRUE)


write.csv(suitable_country_ref2,"PATH/SDM/R/suitable_country_ref2.csv")
write.csv(suitable_country_ref_cr,"PATH/SDM/R/suitable_country_ref_cr.csv")

wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack_cropl_nWDPA<-mask(wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack,spam_cropland_nWDPA_shp)
wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack_cropl_nWDPA<-crop(wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack_cropl_nWDPA,spam_cropland_nWDPA_shp)
suitable_crop_country_ref<-extract(wild_dom_ef_5arcmin_EMwmeanByTSS_TSSbin_stack_cropl_nWDPA,boundary_study_reg,method="simple", fun= "sum", cellnumbers=TRUE, na.rm=TRUE, df=TRUE)
suitable_crop_country_ref<-cbind(boundary_study_reg$NAME_0,suitable_crop_country_ref)
write.csv2(suitable_country_ref,"PATH/SDM/R/suitable_country_ref.csv")

